import { CssBaseline, ThemeProvider, createTheme } from '@mui/material'
import { BrowserRouter, Route, Routes } from 'react-router'
import { MaAppBar } from '@renderer/components/MaAppBar'
import Landing from '@renderer/pages/Landing'

import { useUserStore } from 'solar-js-sdk'
import { useEffect } from 'react'

import ProductDetails from './pages/products/Details'
import Tasks from './pages/Tasks'
import Library from './pages/Library'
import LibraryDetails from './pages/library/Details'

function App(): JSX.Element {
  const userStore = useUserStore()

  useEffect(() => {
    userStore.fetchUser()
  }, [])

  const appTheme = createTheme({
    cssVariables: true,
    colorSchemes: {
      dark: true,
    },
    palette: {
      mode: 'light',
      primary: {
        main: '#3949ab',
      },
      secondary: {
        main: '#1e88e5',
      },
    },
  })

  return (
    <ThemeProvider theme={appTheme}>
      <BrowserRouter>
        <CssBaseline />

        <MaAppBar />

        <Routes>
          <Route path="/" element={<Landing />} />
          <Route path="/tasks" element={<Tasks />} />
          <Route path="/library" element={<Library />} />
          <Route path="/products/:id" element={<ProductDetails />} />
          <Route path="/library/:id" element={<LibraryDetails />} />
        </Routes>
      </BrowserRouter>
    </ThemeProvider>
  )
}

export default App
