import {
  Box,
  Container,
  Typography,
  Grid2 as Grid,
  Card,
  CardContent,
  CardMedia,
  CardActionArea,
  Avatar,
} from '@mui/material'
import { useEffect, useState } from 'react'
import { useNavigate } from 'react-router'
import { MaProduct, getAttachmentUrl, sni } from 'solar-js-sdk'

export default function Landing(): JSX.Element {
  const navigate = useNavigate()

  const [products, setProducts] = useState<MaProduct[]>([])

  async function fetchProducts(): Promise<void> {
    const { data: resp } = await sni.get<{ data: MaProduct[] }>('/cgi/ma/products', {
      params: {
        take: 10,
      },
    })
    setProducts(resp.data)
  }

  useEffect(() => {
    fetchProducts()
  }, [])

  return (
    <Container sx={{ py: 4, display: 'flex', flexDirection: 'column', gap: 2 }}>
      <Box>
        <Typography variant="h5" component="div">
          Matrix Marketplace
        </Typography>
      </Box>

      <Grid container columns={{ xs: 1, sm: 2, md: 3 }} spacing={2}>
        {products.map((p) => (
          <Grid size={1} key={p.id}>
            <Card>
              <CardActionArea onClick={() => navigate('/products/' + p.id)}>
                {p.previews && (
                  <CardMedia
                    sx={{ aspectRatio: 16 / 5 }}
                    image={getAttachmentUrl(p.previews[0])}
                    title="green iguana"
                  />
                )}
                <CardContent>
                  {p.icon && (
                    <Avatar
                      variant="rounded"
                      src={getAttachmentUrl(p.icon)}
                      sx={{
                        width: 48,
                        height: 48,
                        border: 1,
                        borderColor: 'divider',
                        borderRadius: 4,
                        mb: 0.75,
                        mx: '-4px',
                      }}
                    />
                  )}
                  <Typography variant="h5" component="div">
                    {p.name}
                  </Typography>
                  <Typography variant="body2" component="div">
                    {p.description}
                  </Typography>
                </CardContent>
              </CardActionArea>
            </Card>
          </Grid>
        ))}
      </Grid>
    </Container>
  )
}
