import { LocalAppRecord } from '@main/library'
import {
  Avatar,
  Card,
  CardActionArea,
  CardContent,
  CardMedia,
  Container,
  Grid2 as Grid,
  Typography,
} from '@mui/material'
import { useEffect, useState } from 'react'
import { useNavigate } from 'react-router'
import { getAttachmentUrl } from 'solar-js-sdk'

export default function Library(): JSX.Element {
  const navigate = useNavigate()

  const [apps, setApps] = useState<LocalAppRecord[]>([])

  function fetchApps() {
    window.electron.ipcRenderer.invoke('get-app-library').then((res) => setApps(JSON.parse(res)))
  }

  useEffect(() => {
    fetchApps()
  }, [])

  return (
    <Container sx={{ py: 4, display: 'flex', flexDirection: 'column', gap: 2 }}>
      <Typography variant="h5" component="h1">
        Library
      </Typography>

      <Grid container columns={{ xs: 1, sm: 2, md: 3 }} spacing={2}>
        {apps.map((p) => (
          <Grid size={1} key={p.id}>
            <Card>
              <CardActionArea onClick={() => navigate('/library/' + p.id)}>
                {p.product.previews && (
                  <CardMedia
                    sx={{ aspectRatio: 16 / 5 }}
                    image={getAttachmentUrl(p.product.previews[0])}
                    title="green iguana"
                  />
                )}
                <CardContent>
                  {p.product.icon && (
                    <Avatar
                      variant="rounded"
                      src={getAttachmentUrl(p.product.icon)}
                      sx={{
                        width: 48,
                        height: 48,
                        border: 1,
                        borderColor: 'divider',
                        borderRadius: 4,
                        mb: 0.75,
                        mx: '-4px',
                      }}
                    />
                  )}
                  <Typography variant="h5" component="div">
                    {p.product.name}
                  </Typography>
                  <Typography variant="body2" component="div" gutterBottom>
                    {p.product.description}
                  </Typography>

                  <Typography fontSize={13} fontWeight="bold">
                    Installed
                  </Typography>
                  <Typography variant="subtitle1" fontSize={14} lineHeight={1}>
                    {p.release.meta.title} {p.release.version}
                  </Typography>
                </CardContent>
              </CardActionArea>
            </Card>
          </Grid>
        ))}
      </Grid>
    </Container>
  )
}
